diff --git a/drivers/net/netconsole.c b/drivers/net/netconsole.c
--- a/drivers/net/netconsole.c
+++ b/drivers/net/netconsole.c
@@ -67,7 +67,7 @@ __setup("netconsole=", option_setup);
 /* Linked list of all configured targets */
 static LIST_HEAD(target_list);
 
 /* This needs to be a spinlock because write_msg() cannot sleep */
 static DEFINE_SPINLOCK(target_list_lock);
 
 /**
@@ -694,7 +694,7 @@ static struct notifier_block netconsole_
 	.notifier_call  = netconsole_netdev_event,
 };
 
-static void write_msg(struct console *con, const char *msg, unsigned int len)
+static void netconsole_write_msg(const char *msg, unsigned int len)
 {
 	int frag, left;
 	unsigned long flags;
@@ -728,10 +728,15 @@ static void write_msg(struct console *co
 	spin_unlock_irqrestore(&target_list_lock, flags);
 }
 
+static void netconsole_console_write(struct console *con, const char *msg, unsigned int len)
+{
+	netconsole_write_msg(msg, len);
+}
+
 static struct console netconsole = {
 	.name	= "netcon",
 	.flags	= CON_ENABLED,
-	.write	= write_msg,
+	.write	= netconsole_console_write,
 };
 
 static int __init init_netconsole(void)
@@ -67,7 +67,7 @@ __setup("netconsole=", option_setup);
 static LIST_HEAD(target_list);
 
-/* This needs to be a spinlock because write_msg() cannot sleep */
+/* This needs to be a spinlock because netconsole_write_msg() cannot sleep */
 static DEFINE_SPINLOCK(target_list_lock);
 
